<?php

declare(strict_types=1);

/**
 * @file
 * Theme settings form for Graupl theme.
 */

use Drupal\Core\Form\FormState;

/**
 * Implements hook_form_system_theme_settings_alter().
 */
function graupl_form_system_theme_settings_alter(array &$form, FormState $form_state): void {

  // Get the theme settings.
  $config = \Drupal::configFactory()->getEditable('graupl.settings');

  $form['graupl'] = [
    '#type' => 'details',
    '#title' => t('Graupl'),
    '#open' => TRUE,
  ];

  $form['graupl']['library'] = [
    '#type' => 'fieldset',
    '#title' => t('Library settings'),
    '#tree' => TRUE,
  ];

  $form['graupl']['library']['installation'] = [
    '#type' => 'select',
    '#title' => t('Installation method'),
    '#description' => t('Choose if you want to use a local library or an external CDN to load the library.'),
    '#options' => [
      'cdn' => t('CDN'),
      'local' => t('Local'),
    ],
    '#default_value' => $config->get('library')['installation'] ?? 'cdn',
    '#required' => TRUE,
  ];

  $form['graupl']['library']['cdn'] = [
    '#type' => 'select',
    '#title' => t('Select a CDN provider'),
    '#description' => t('Choose the CDN provider you want to use to load the library.'),
    '#options' => [
      'jsdelivr' => t('jsDelivr'),
      'unpkg' => t('unpkg'),
    ],
    '#default_value' => $config->get('library')['cdn'] ?? 'jsdelivr',
    '#states' => [
      'visible' => [
        'select[name="library[installation]"]' => ['value' => 'cdn'],
      ],
    ],
  ];

  $form['graupl']['library']['version'] = [
    '#type' => 'textfield',
    '#title' => t('Library version'),
    '#description' => t('Enter the version of the library you want to use. Use "latest" to always load the latest version.'),
    '#default_value' => $config->get('library')['version'] ?? 'latest',
    '#states' => [
      'visible' => [
        'select[name="library[installation]"]' => ['value' => 'cdn'],
      ],
    ],
  ];

  $form['graupl']['properties'] = [
    '#type' => 'fieldset',
    '#title' => t('Custom property overrides'),
    '#tree' => TRUE,
  ];

  $form['graupl']['properties']['enabled'] = [
    '#type' => 'checkbox',
    '#title' => t('Enable custom property overrides'),
    '#description' => t('Enable this option to override the default custom properties.'),
    '#default_value' => $config->get('properties')['enabled'] ?? FALSE,
  ];

  $form['graupl']['properties']['prefix'] = [
    '#type' => 'textfield',
    '#title' => t('Prefix'),
    '#description' => t('The prefix for all graupl custom properties. Only change this if you know what you are doing.'),
    '#default_value' => $config->get('properties')['prefix'] ?? 'graupl-',
    '#states' => [
      'visible' => [
        'input[name="properties[enabled]"]' => ['checked' => TRUE],
      ],
    ],
  ];

  $form['graupl']['properties']['content_max_width'] = [
    '#type' => 'textfield',
    '#title' => t('Content max width'),
    '#description' => t('The maximum width of the content area.'),
    '#default_value' => $config->get('properties')['content_max_width'] ?? '96ch',
    '#states' => [
      'visible' => [
        'input[name="properties[enabled]"]' => ['checked' => TRUE],
      ],
    ],
  ];

  $form['graupl']['properties']['container_breakout_section_min_width'] = [
    '#type' => 'textfield',
    '#title' => t('Container breakout section min width'),
    '#description' => t('The minimum width of the container breakout section.'),
    '#default_value' => $config->get('properties')['container_breakout_section_min_width'] ?? '0rem',
    '#states' => [
      'visible' => [
        'input[name="properties[enabled]"]' => ['checked' => TRUE],
      ],
    ],
  ];

  $form['graupl']['properties']['container_breakout_section_max_width'] = [
    '#type' => 'textfield',
    '#title' => t('Container breakout section max width'),
    '#description' => t('The maximum width of the container breakout section.'),
    '#default_value' => $config->get('properties')['container_breakout_section_max_width'] ?? '7.5rem',
    '#states' => [
      'visible' => [
        'input[name="properties[enabled]"]' => ['checked' => TRUE],
      ],
    ],
  ];

  $form['graupl']['properties']['container_feature_section_min_width'] = [
    '#type' => 'textfield',
    '#title' => t('Container feature section min width'),
    '#description' => t('The minimum width of the container feature section.'),
    '#default_value' => $config->get('properties')['container_feature_section_min_width'] ?? '0rem',
    '#states' => [
      'visible' => [
        'input[name="properties[enabled]"]' => ['checked' => TRUE],
      ],
    ],
  ];

  $form['graupl']['properties']['container_feature_section_max_width'] = [
    '#type' => 'textfield',
    '#title' => t('Container feature section max width'),
    '#description' => t('The maximum width of the container feature section.'),
    '#default_value' => $config->get('properties')['container_feature_section_max_width'] ?? '10rem',
    '#states' => [
      'visible' => [
        'input[name="properties[enabled]"]' => ['checked' => TRUE],
      ],
    ],
  ];

  $form['graupl']['properties']['container_full_width_section_min_width'] = [
    '#type' => 'textfield',
    '#title' => t('Container full width section min width'),
    '#description' => t('The minimum width of the container full width section.'),
    '#default_value' => $config->get('properties')['container_full_width_section_min_width'] ?? '1rem',
    '#states' => [
      'visible' => [
        'input[name="properties[enabled]"]' => ['checked' => TRUE],
      ],
    ],
  ];
}
